@@ -61,7 +61,7 @@ static gboolean m_bKeysizePriority;
 static gboolean m_bWordCompleteOn;
 static gboolean m_bCommandPredictOn;
 static gint m_NumberPredictions;
-static char NameAccessMethod [MAX_ACCESS_METHOD_NAME];
+static gchar *m_NameAccessMethod = NULL;
 static gboolean m_bUseGtkPlusTheme;
 static gboolean m_bDriveCorePointer = FALSE;
 static gboolean m_bExpandWindow;
@@ -158,8 +158,8 @@ GokSetting* gok_data_construct_setting (void)
 
 	pSetting = (GokSetting*) g_malloc(sizeof(GokSetting));
 
-	pSetting->Name[0] = 0;
-	pSetting->NameAccessMethod[0] = 0;
+	pSetting->Name = NULL;
+	pSetting->NameAccessMethod = NULL;
 	pSetting->pValueString = NULL;
 	pSetting->pValueStringBackup = NULL;
 	pSetting->Value = 0;
@@ -240,15 +240,17 @@ gboolean gok_data_read_settings (void)
         gok_gconf_get_string (gconf_client, GOK_GCONF_AUX_DICTS, 
 			         &m_AuxDicts);
 
-	gok_gconf_get_string (gconf_client, GOK_GCONF_DOCK_TYPE,
-			      &a_gchar);
-        m_eDockType = gok_data_dock_type_from_string (a_gchar);
-	g_free (a_gchar);
+	if (gok_gconf_get_string (gconf_client, GOK_GCONF_DOCK_TYPE,
+			      &a_gchar)) {
+            m_eDockType = gok_data_dock_type_from_string (a_gchar);
+	    g_free (a_gchar);
+	}
 
-	gok_gconf_get_string (gconf_client, GOK_GCONF_COMPOSE_KBD_TYPE,
-			      &a_gchar);
-        compose_keyboard_type = gok_data_compose_type_from_string (a_gchar);
-	g_free (a_gchar);
+	if (gok_gconf_get_string (gconf_client, GOK_GCONF_COMPOSE_KBD_TYPE,
+			      &a_gchar)) {
+            compose_keyboard_type = gok_data_compose_type_from_string (a_gchar);
+	    g_free (a_gchar);
+	}
 
 	/* Read in settings for individual access methods */
 	access_method_dirs
@@ -311,13 +313,8 @@ gboolean gok_data_read_settings (void)
 			    }
 
 			    /* Populate the setting structure */
-			    strncpy (pSetting->NameAccessMethod,
-				     access_method_name,
-				     MAX_ACCESS_METHOD_NAME);
-
-			    strncpy (pSetting->Name,
-				     setting_name,
-				     MAX_RATE_NAME);
+			    pSetting->Name = g_strdup (setting_name);
+			    pSetting->NameAccessMethod = g_strdup (access_method_name);
 
 			    if (a_gconfvalue->type == GCONF_VALUE_INT)
 			    {
@@ -326,11 +323,7 @@ gboolean gok_data_read_settings (void)
 			    }
 			    else if (a_gconfvalue->type == GCONF_VALUE_STRING)
 			    {
-				pSetting->pValueString = (gchar*)g_malloc (
-				    strlen (gconf_value_get_string (
-					a_gconfvalue)) + 1);
-				strcpy (pSetting->pValueString,
-					gconf_value_get_string (a_gconfvalue));
+				pSetting->pValueString = g_strdup (gconf_value_get_string (a_gconfvalue));
 			    }
 
 			    /* Link the new setting structure into the list */
@@ -377,6 +370,7 @@ void gok_data_close (void)
 		pSetting = pSetting->pSettingNext;
 		g_free (pSettingTemp);
 	}
+	g_free (m_NameAccessMethod);
 }
 
 /**
@@ -399,8 +393,7 @@ gboolean gok_data_get_control_values (GokControl* pControl)
 				{
 					g_free (pControl->Name);
 				}
-				pControl->Name = (gchar*)g_malloc (strlen (settingString) + 1);
-				strcpy (pControl->Name, settingString);
+				pControl->Name = g_strdup (settingString);
 			}
 			break;
 
@@ -475,9 +468,8 @@ gok_data_fill_setting_values (gint settingValue, gchar *settingValueString, gint
 gboolean gok_data_get_setting (gchar* NameAccessMethod, gchar* NameSetting, gint* Value, gchar** ValueString)
 {
 	gchar* pPlus;
-	gchar buffer[100];
-	gint count;
 	GokSetting* pSetting;
+	gchar *FirstNameSetting;
 
 	g_assert (NameAccessMethod != NULL);
 	g_assert (NameSetting != NULL);
@@ -486,25 +478,28 @@ gboolean gok_data_get_setting (gchar* NameAccessMethod, gchar* NameSetting, gint
 	if ((pPlus = strrchr (NameSetting, '+')) != NULL)
 	{
 		/* yes, use just the first setting name */
-		count = pPlus - NameSetting;
-		strncpy (buffer, NameSetting, count);
-		buffer[count] = 0;
-		NameSetting = buffer;
+		FirstNameSetting = g_strndup (NameSetting, pPlus - NameSetting);
+	} 
+	else
+	{
+		FirstNameSetting = g_strdup (NameSetting);
 	}
 	
 	/* first look to see if we have a commandline override for the setting */
 	if (gok_main_get_scan_override () && !strcmp (gok_data_get_name_accessmethod (), NameAccessMethod) && 
-	    !strcmp (NameSetting, "movehighlighter") && gok_action_find_action (gok_main_get_scan_override (), FALSE))
+	    !strcmp (FirstNameSetting, "movehighlighter") && gok_action_find_action (gok_main_get_scan_override (), FALSE))
 	{
 		gok_data_fill_setting_values (0, gok_main_get_scan_override (), Value, ValueString);
+		g_free (FirstNameSetting);
 		return TRUE;
 	}
 	else if (gok_main_get_select_override () && 
 		 !strcmp (gok_data_get_name_accessmethod (), NameAccessMethod) &&
-		 (!strcmp (NameSetting, "select") || !strcmp (NameSetting, "outputselected"))
+		 (!strcmp (FirstNameSetting, "select") || !strcmp (FirstNameSetting, "outputselected"))
 		 && gok_action_find_action (gok_main_get_select_override (), FALSE))
 	{
 		gok_data_fill_setting_values (0, gok_main_get_select_override (), Value, ValueString);
+		g_free (FirstNameSetting);
 		return TRUE;
 	}
 	else
@@ -515,14 +510,16 @@ gboolean gok_data_get_setting (gchar* NameAccessMethod, gchar* NameSetting, gint
 		{
 			/* check if this setting has the same access method name and setting name as given */
 			if ((strcmp (pSetting->NameAccessMethod, NameAccessMethod) == 0) &&
-			    (strcmp (pSetting->Name, NameSetting) == 0))
+			    (strcmp (pSetting->Name, FirstNameSetting) == 0))
 			{
 				gok_data_fill_setting_values (pSetting->Value, pSetting->pValueString, Value, ValueString);
+		    		g_free (FirstNameSetting);
 				return TRUE;
 			}
 			pSetting = pSetting->pSettingNext;
 		}
 	}
+	g_free (FirstNameSetting);
 	return FALSE;
 }
 
@@ -543,18 +540,19 @@ gboolean gok_data_set_setting (gchar* NameAccessMethod, gchar* NameSetting, gint
 {
 	GokSetting* pSetting;
 	gchar* pTokenSettingName;
-	gchar buffer[150];
 	gchar* pkey;
+	gchar **tokens;
+	gint i;
 	gboolean codeReturned;
 
 	codeReturned = FALSE;
 	
 	/* there may be more than one setting specified in NameSetting */
 	/* each setting is seperated by a "+" */
-	strcpy (buffer, NameSetting);
-	pTokenSettingName = strtok (buffer, "+");
-	while (pTokenSettingName != NULL)
+	tokens = g_strsplit (NameSetting, "+", 0);
+	for (i = 0; tokens [i] != NULL; i++)
 	{
+		pTokenSettingName = tokens [i];
 		/* find the setting in the list */
 		pSetting = m_pSettingFirst;
 		while (pSetting != NULL)
@@ -577,8 +575,7 @@ gboolean gok_data_set_setting (gchar* NameAccessMethod, gchar* NameSetting, gint
 							g_free (pSetting->pValueString);
 						}
 						
-						pSetting->pValueString = (gchar*)g_malloc (strlen (ValueString) + 1);
-						strcpy (pSetting->pValueString, ValueString);
+						pSetting->pValueString = g_strdup (ValueString);
 						
 						gok_log ("Writing %s = %s to GConf", pkey, ValueString);
 		    			gok_gconf_set_string (gconf_client, pkey, ValueString);
@@ -609,8 +606,8 @@ gboolean gok_data_set_setting (gchar* NameAccessMethod, gchar* NameSetting, gint
 			gok_log_x ("Can't find setting! Access method = %s, setting name = %s.", NameAccessMethod, pTokenSettingName);
 		}
 
-		pTokenSettingName = strtok (NULL, "+");
 	}
+	g_strfreev (tokens);
 
 	return codeReturned;
 }
@@ -640,13 +637,12 @@ gboolean gok_data_create_setting (gchar* NameAccessMethod, gchar* NameSetting, g
 	}
 
 	/* populate the setting structure */
-	strcpy (pSetting->NameAccessMethod, NameAccessMethod);
-	strcpy (pSetting->Name, NameSetting);
+	pSetting->NameAccessMethod = g_strdup (NameAccessMethod);
+	pSetting->Name = g_strdup (NameSetting);
 	pSetting->Value = Value;
 	if (pValueString != NULL)
 	{
-		pSetting->pValueString = (gchar*)g_malloc (strlen (pValueString) + 1);
-		strcpy (pSetting->pValueString, pValueString);
+		pSetting->pValueString = g_strdup (pValueString);
 	}
 
 	/* link the new setting structure into the list */
@@ -896,12 +892,13 @@ void gok_data_set_keysize_priority (gboolean bFlag)
 static void 
 gok_data_set_name_accessmethod_internal (const char* Name)
 {
-	if (strcmp (Name, NameAccessMethod) == 0)
+	if (m_NameAccessMethod != NULL && strcmp (Name, m_NameAccessMethod) == 0)
 	{
 		return;
 	}
 
-	strncpy (NameAccessMethod, Name, MAX_ACCESS_METHOD_NAME);
+	g_free (m_NameAccessMethod);
+	m_NameAccessMethod = g_strdup (Name);
 	m_bSettingsChanged = TRUE;
 }
 	
@@ -919,13 +916,13 @@ void gok_data_set_name_accessmethod (const char* Name)
 		return; /*TODO revisit this behavior */
 	}
 
-	if (strcmp (Name, NameAccessMethod) == 0)
+	if (m_NameAccessMethod != NULL && strcmp (Name, m_NameAccessMethod) == 0)
 	{
 		return;
 	}
 
 	gok_gconf_set_string (gconf_client, GOK_GCONF_ACCESS_METHOD,
-				   Name);
+			      Name);
 	gok_data_set_name_accessmethod_internal (Name);
 }
 	
@@ -940,7 +937,7 @@ char* gok_data_get_name_accessmethod ()
 	{
 		return gok_main_get_access_method_override();
 	}
-	return NameAccessMethod;
+	return m_NameAccessMethod;
 }
 
 /**
@@ -1171,8 +1168,7 @@ void gok_data_backup_setting (GokSetting* pSetting)
 				g_free (pSetting->pValueStringBackup);
 			}
 			
-			pSetting->pValueStringBackup = (gchar*)g_malloc (strlen (pSetting->pValueString) + 1);
-			strcpy (pSetting->pValueStringBackup, pSetting->pValueString);
+			pSetting->pValueStringBackup = g_strdup (pSetting->pValueString);
 		}
 	}
 
@@ -1215,8 +1211,7 @@ gboolean gok_data_restore_setting (GokSetting* pSetting)
 			{
 				g_free (pSetting->pValueString);
 			}
-			pSetting->pValueString = (gchar*)g_malloc (strlen (pSetting->pValueStringBackup) + 1);
-			strcpy (pSetting->pValueString, pSetting->pValueStringBackup);
+			pSetting->pValueString = g_strdup (pSetting->pValueStringBackup);
 
 			codeReturned = TRUE;
 		}
