@@ -25,12 +25,12 @@
 #endif
 
 #include <gnome.h>
+#include <glade/glade.h>
 #include "gok-log.h"
 #include "gok-keyboard.h"
 #include "gok-editor.h"
 #include "gok-modifier.h"
-#include "interface.h"
-#include "support.h"
+#include "gok-glade-helpers.h"
 
 #define TITLE_GOK_EDITOR _("GOK Keyboard Editor")
 
@@ -40,6 +40,10 @@ static GtkWindowGroup* m_pWindowGroup;
 /* pointer to the window that displays the key parameters */
 static GtkWidget* m_pWindowEditor = NULL;
 
+/* pointer to the glade xml structure for the window that 
+ * displays the key parameters */
+static GladeXML* m_pEditorXML = NULL;
+
 /* pointer to the window that displays the keyboard */
 static GtkWidget* m_pWindowKeyboard;
 
@@ -76,7 +80,9 @@ void gok_editor_run()
 	m_bSkipUpdate = TRUE;
 	
 	/* create the parameters dialog */
-	m_pWindowEditor = (GtkWidget*)create_windowEditor();
+	m_pEditorXML = gok_glade_xml_new("gok.glade2", "windowEditor");
+	m_pWindowEditor = glade_xml_get_widget(m_pEditorXML, "windowEditor");
+	g_assert(m_pWindowEditor != NULL);
 	gtk_widget_show (m_pWindowEditor);
 	
 	/* create the keyboard window */
@@ -243,12 +249,13 @@ void gok_editor_new_file ()
 */
 void gok_editor_open_file()
 {
-	GtkFileSelection* pDialogFilename;
+	GtkWidget* pDialogFilename;
 	GtkWidget* pDialog;
 	gint response;
-	const gchar* filename;
+	gchar* filename;
 	GtkWidget* pEntry;
 	GokKey* pKey;
+	GtkFileFilter *filter;
 	
 	if (m_bFileModified == TRUE)
 	{
@@ -269,34 +276,43 @@ void gok_editor_open_file()
 	}
 
 	/* create the file selector dialog */
-	pDialogFilename = (GtkFileSelection*)gtk_file_selection_new (_("Select keyboard file for editing"));
+	pDialogFilename = gtk_file_chooser_dialog_new (_("Select keyboard file for editing"),
+						       GTK_WINDOW(m_pWindowEditor),
+						       GTK_FILE_CHOOSER_ACTION_OPEN,
+						       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						       GTK_STOCK_OPEN, GTK_RESPONSE_OK,
+						       NULL);
 
 	/* display only .kbd files */
 	/* TODO - this is not working! Why?? */
-	gtk_file_selection_complete (pDialogFilename, "*.kbd");
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (filter, _(".kbd files"));
+	gtk_file_filter_add_pattern (filter, "*.kbd");
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(pDialogFilename), filter);
 	
-   /* display that file selector dialog */
+	/* display that file selector dialog */
 	response = gtk_dialog_run (GTK_DIALOG(pDialogFilename));
 
-	if (response == GTK_RESPONSE_CANCEL)
+	if (response != GTK_RESPONSE_OK)
 	{
 		/* destroy the file selector dialog */
-		gtk_widget_destroy (GTK_WIDGET(pDialogFilename));
+		gtk_widget_destroy (pDialogFilename);
 
 		return;
 	}
 	
 	/* get the file name */
-	filename = gtk_file_selection_get_filename (pDialogFilename);
+	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER(pDialogFilename));
 	
 	/* is this a GOK keyboard file? */
 	if ((strlen(filename) < 4) ||
 		(strcmp(filename + (strlen(filename)-4), ".kbd") != 0))
 	{
 		/* no, destroy the file selector dialog */
-		gtk_widget_destroy (GTK_WIDGET(pDialogFilename));
+		gtk_widget_destroy (pDialogFilename);
 
-		gok_editor_message_filename_bad ((gchar*)filename);		
+		gok_editor_message_filename_bad (filename);
+		g_free (filename);
 		return;
 	}
 	
@@ -305,11 +321,10 @@ void gok_editor_open_file()
 	{
 		g_free (m_pFilename);
 	}
-	m_pFilename = (gchar*)g_malloc (strlen (filename) + 1);
-	strcpy (m_pFilename, filename);
+	m_pFilename = filename;
 	
 	/* destroy the file selector dialog */
-	gtk_widget_destroy (GTK_WIDGET(pDialogFilename));
+	gtk_widget_destroy (pDialogFilename);
 
 	/* delete the previous keyboard */
 	if (m_pKeyboard != NULL)
@@ -338,7 +353,7 @@ void gok_editor_open_file()
 	
 	/* display info about the keyboard */
 	/* keyboard name */
-	pEntry = (GtkWidget*)lookup_widget (m_pWindowEditor, "entryKeyboardName");
+	pEntry = glade_xml_get_widget (m_pEditorXML, "entryKeyboardName");
 	g_assert (pEntry != NULL);
 	gtk_entry_set_text (GTK_ENTRY(pEntry), gok_keyboard_get_name(m_pKeyboard));
 	
@@ -386,7 +401,7 @@ void gok_editor_show_parameters (GokKey* pKey)
 	gok_log_enter();
 
 	/* normal key label */
-	pEntryLabel = (GtkWidget*)lookup_widget (m_pWindowEditor, "entryLabel");
+	pEntryLabel = glade_xml_get_widget (m_pEditorXML, "entryLabel");
 	g_assert (pEntryLabel != NULL);
 
 	if (pKey == NULL)
@@ -405,16 +420,16 @@ void gok_editor_show_parameters (GokKey* pKey)
 	gtk_entry_set_text (GTK_ENTRY(pEntryLabel), gok_key_get_label (pKey));
 
 	/* location */
-	pSpin = (GtkWidget*)lookup_widget (m_pWindowEditor, "spinLeft");
+	pSpin = glade_xml_get_widget (m_pEditorXML, "spinLeft");
 	g_assert (pSpin != NULL);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pSpin), pKey->Left);
-	pSpin = (GtkWidget*)lookup_widget (m_pWindowEditor, "spinRight");
+	pSpin = glade_xml_get_widget (m_pEditorXML, "spinRight");
 	g_assert (pSpin != NULL);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pSpin), pKey->Right);
-	pSpin = (GtkWidget*)lookup_widget (m_pWindowEditor, "spinTop");
+	pSpin = glade_xml_get_widget (m_pEditorXML, "spinTop");
 	g_assert (pSpin != NULL);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pSpin), pKey->Top);
-	pSpin = (GtkWidget*)lookup_widget (m_pWindowEditor, "spinBottom");
+	pSpin = glade_xml_get_widget (m_pEditorXML, "spinBottom");
 	g_assert (pSpin != NULL);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pSpin), pKey->Bottom);
 
@@ -526,7 +541,7 @@ void gok_editor_add_key ()
 		pNewKey->Left = col;
 		pNewKey->Right = col + 1;
 		gok_log("adding key {top [%d] bottom [%d] left [%d] right [%d]}",pNewKey->Top,pNewKey->Bottom,pNewKey->Left,pNewKey->Right);
-		gok_key_add_label (pNewKey, _("label"), 0, 0);
+		gok_key_add_label (pNewKey, _("label"), 0, 0, NULL);
 		
 		gok_editor_touch_file(TRUE);
 		gok_editor_update_keyboard(m_pKeyboard);
@@ -595,19 +610,19 @@ void gok_editor_update_key()
 	if (m_bSkipUpdate == FALSE)
 	{
 		/* location */
-		pSpin = (GtkWidget*)lookup_widget (m_pWindowEditor, "spinLeft");
+		pSpin = glade_xml_get_widget (m_pEditorXML, "spinLeft");
 		g_assert (pSpin != NULL);
 		left = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(pSpin));
 		
-		pSpin = (GtkWidget*)lookup_widget (m_pWindowEditor, "spinRight");
+		pSpin = glade_xml_get_widget (m_pEditorXML, "spinRight");
 		g_assert (pSpin != NULL);
 		right = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(pSpin));
 		
-		pSpin = (GtkWidget*)lookup_widget (m_pWindowEditor, "spinTop");
+		pSpin = glade_xml_get_widget (m_pEditorXML, "spinTop");
 		g_assert (pSpin != NULL);
 		top = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(pSpin));
 		
-		pSpin = (GtkWidget*)lookup_widget (m_pWindowEditor, "spinBottom");
+		pSpin = glade_xml_get_widget (m_pEditorXML, "spinBottom");
 		g_assert (pSpin != NULL);
 		bottom = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(pSpin));
 		
@@ -799,10 +814,9 @@ gboolean gok_editor_save_keyboard (GokKeyboard* pKeyboard, gchar* Filename)
 		while (pLabel != NULL)
 		{
 			fputs ("\t\t<GOK:label", pFile);
-			if (pLabel->modifiers != 0)
-			{
-				fprintf (pFile, " modifier=\"%s\"", 
-					 gok_modifier_first_name_from_mask (pLabel->modifiers));
+			if (pLabel->level != 0)			{
+				fprintf (pFile, " level=\"%d\"", 
+					 pLabel->level);
 			}
 			fprintf (pFile, ">%s</GOK:label>\n", pLabel->Text);
 			
@@ -943,9 +957,10 @@ gboolean gok_editor_save_current_keyboard ()
 */
 gboolean gok_editor_save_current_keyboard_as ()
 {
-	GtkFileSelection* pDialogFilename;
+	GtkWidget* pDialogFilename;
 	gint response;
-	const gchar* filename;
+	gchar* filename;
+	GtkFileFilter *filter;
 	
 	if (m_pKeyboard != NULL)
 	{
@@ -953,33 +968,42 @@ gboolean gok_editor_save_current_keyboard_as ()
 		{
 			/* get name of keyboard filename */
 			/* create the file selector dialog */
-			pDialogFilename = (GtkFileSelection*)gtk_file_selection_new ("Save keyboard file as");
-		
+			pDialogFilename = gtk_file_chooser_dialog_new (_("Save keyboard file as"),
+								       GTK_WINDOW(m_pWindowEditor),
+								       GTK_FILE_CHOOSER_ACTION_SAVE,
+								       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+								       GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+								       NULL);
+
 			/* display only .kbd files */
 			/* TODO - this is not working! Why?? */
-			gtk_file_selection_complete (pDialogFilename, "*.kbd");
-			
-		   /* display that file selector dialog */
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, _(".kbd files"));
+			gtk_file_filter_add_pattern (filter, "*.kbd");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(pDialogFilename), filter);
+	
+			/* display that file selector dialog */
 			response = gtk_dialog_run (GTK_DIALOG(pDialogFilename));
 		
-			if (response == GTK_RESPONSE_CANCEL)
+			if (response != GTK_RESPONSE_OK)
 			{
 				/* destroy the file selector dialog */
-				gtk_widget_destroy (GTK_WIDGET(pDialogFilename));
+				gtk_widget_destroy (pDialogFilename);
 				return FALSE;
 			}
 			
 			/* get the file name */
-			filename = gtk_file_selection_get_filename (pDialogFilename);
+			filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (pDialogFilename));
 			
 			/* is this a GOK keyboard file? */
 			if ((strlen(filename) < 4) ||
 				(strcmp(filename + (strlen(filename)-4), ".kbd") != 0))
 			{
 				/* no, destroy the file selector dialog */
-				gtk_widget_destroy (GTK_WIDGET(pDialogFilename));
+				gtk_widget_destroy (pDialogFilename);
 				
-				gok_editor_message_filename_bad ((gchar*)filename);		
+				gok_editor_message_filename_bad (filename);
+				g_free (filename);
 				return FALSE;
 			}
 			
@@ -988,14 +1012,13 @@ gboolean gok_editor_save_current_keyboard_as ()
 			{
 				g_free (m_pFilename);
 			}
-			m_pFilename = (gchar*)g_malloc (strlen (filename) + 1);
-			strcpy (m_pFilename, filename);
+			m_pFilename = filename;
 			
 			/* destroy the file selector dialog */
-			gtk_widget_destroy (GTK_WIDGET(pDialogFilename));
+			gtk_widget_destroy (pDialogFilename);
 
 			/* save the keyboard under this filename */
-			gok_editor_save_keyboard (m_pKeyboard, (gchar*)filename);
+			gok_editor_save_keyboard (m_pKeyboard, filename);
 		}
 	}
 	
@@ -1024,19 +1047,21 @@ gboolean gok_editor_validate_keyboard (GokKeyboard* pKeyboard)
 void gok_editor_message_filename_bad (gchar* Filename)
 {
 	GtkWidget* pDialog;
-	gchar buffer[101];
+	gchar *buffer;
 
-	sprintf (buffer, _("This is not a valid keyboard filename:\n%s"), Filename);
+	buffer = g_strdup_printf (_("This is not a valid keyboard filename:\n%s"),
+				  Filename);
 
 	pDialog = gtk_message_dialog_new (GTK_WINDOW(m_pWindowEditor),
 				GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_MESSAGE_ERROR,
 				GTK_BUTTONS_CLOSE,
-				_(buffer));
+				"%s", buffer);
 
 	gtk_window_set_title (GTK_WINDOW (pDialog), _("Keyboard Filename Invalid"));
 	gtk_dialog_run (GTK_DIALOG (pDialog));
 	gtk_widget_destroy (pDialog);
+	g_free (buffer);
 }
 
 /**
