@@ -56,8 +56,7 @@ gchar m_label[XkbKeyNameLength + 1];
 
 gint m_Group = 0; /* FIXME: statics are bad */
 
-#undef GOK_UTF8_DEBUG
-
+#ifdef GOK_UTF8_DEBUG
 static void 
 gok_key_print_utf8_debug (gchar *buf)
 {
@@ -82,6 +81,7 @@ gok_key_print_utf8_debug (gchar *buf)
       }
       fprintf (stderr, "\n");
 }
+#endif
 
 /* returned string must be freed */
 static gchar *
@@ -227,7 +227,7 @@ gok_key_label_from_keysym_string (const gchar *str)
 	gchar *cp;
 	size_t strl;
 
-	if (!str) return g_strdup ("<nil>");
+	if (!str) return g_strdup (_("<nil>"));
 	strl = strlen(str);
 
 	if (!strcmp (str, "KP_Divide")) {
@@ -254,16 +254,16 @@ gok_key_label_from_keysym_string (const gchar *str)
 	else if (!strcmp (str, "KP_End")) {
 		cp = _("End");
 	}
-	else if (!strcmp (str, "KP_Up")) {
+	else if (!strcmp (str, "KP_Up") || !strcmp (str, "Up")) {
 		cp = _("Up");
 	}
-	else if (!strcmp (str, "KP_Down")) {
+	else if (!strcmp (str, "KP_Down") || !strcmp (str, "Down")) {
 		cp = _("Down");
 	}
-	else if (!strcmp (str, "KP_Left")) {
+	else if (!strcmp (str, "KP_Left") || !strcmp (str, "Left")) {
 		cp = _("Left");
 	}
-	else if (!strcmp (str, "KP_Right")) {
+	else if (!strcmp (str, "KP_Right") || !strcmp (str, "Right")) {
 		cp = _("Right");
 	}
 	else if (!strcmp (str, "KP_Begin")) {
@@ -290,12 +290,8 @@ gok_key_label_from_keysym_string (const gchar *str)
 	else if (!strcmp (str, "Mode_switch")) {
 		cp = _("Mode\nswitch");
 	}
-/*      REMOVE COMMENTS POST-BRANCH: freeze applies currently */
  	else if (!strcmp (str, "Hiragana_Katakana")) {
-	        cp = "Hiragana\nKatakana";
-/*
 	        cp = _("Hiragana\nKatakana");
- */
 	}
 	else if (strncmp(str, "KP_", 3) == 0) {
  	        cp = g_strdup (str + 3);
@@ -323,8 +319,6 @@ static unsigned int _numlock_mask = 0xFFFF;
 unsigned int
 gok_key_get_numlock_mask (Display *display)
 {
-	struct gok_modifier_keymask *m;
-
 	if (_numlock_mask == 0xFFFF) {
 		_numlock_mask = XkbKeysymToModifiers (display, XK_Num_Lock);
 	}
@@ -336,7 +330,6 @@ int
 gok_key_get_xkb_type_index (XkbDescPtr xkb, KeyCode keycode, guint group)
 {
 	int num_groups = XkbKeyNumGroups (xkb, keycode);
-	int index;
 	if (!xkb) 
 	        return 1;
 	if (group >= num_groups) 
@@ -425,9 +418,8 @@ static gchar *
 gok_key_label_from_keycode (KeyCode keycode, Display *display, guint level, guint group)
 {
   char buf[20];
-  int extra_rtn, nbytes, state = 0;
+  int extra_rtn, nbytes = 0;
   KeySym keysym = 0;
-  XkbStateRec xkb_state;
   long ucs;
   gunichar unichar;
 
@@ -508,7 +500,6 @@ gok_key_modifier_for_keycode (Display *display, XkbDescPtr xkb, int keycode)
 	guint group = gok_key_get_effective_group ();
 	gint type = gok_key_get_xkb_type_index (xkb, keycode, group);
 	guint modmask = 0;	
-	GokModifier *modifier;
         /* FIXME: assumes modifier bindings don't depend on current modmask! */
 	gint level = gok_key_level_for_type (display, gok_keyboard_get_xkb_desc (), type, &modmask);
 	KeySym keysym = XkbKeycodeToKeysym (display, (KeyCode) keycode, 
@@ -564,13 +555,11 @@ gok_key_from_xkb_key (GokKey *prevKey, GokKeyboard *pKeyboard, Display *display,
 {
   GokKey *pKey;
   gchar *label;
-  gchar name[XkbKeyNameLength + 1];
   gchar keycode_name[8];
   int keycode;
   XkbBoundsRec *pBounds;
-  int width, height, len;
+  int len;
   gboolean is_modifier = FALSE;
-  unsigned int numlock_mask;
   int group, level;
 
   pKey = gok_key_new (prevKey, NULL, pKeyboard);
@@ -830,11 +819,6 @@ gboolean gok_key_initialize (GokKey* pKey, xmlNode* pNode)
 	xmlNode* pNodeWrapperChild;
 	GokOutput* pNewOutput;
 	GokOutput* pOutputTemp;
-	gboolean settings_locked;
-	guint modmask =  
-		SPI_KEYMASK_SHIFT | SPI_KEYMASK_SHIFTLOCK | SPI_KEYMASK_ALT | 
-		SPI_KEYMASK_CONTROL | SPI_KEYMASK_MOD1 | SPI_KEYMASK_MOD2 | SPI_KEYMASK_MOD3 | SPI_KEYMASK_MOD4 |
-		SPI_KEYMASK_MOD5; /* ASSUMPTION: this includes numlock mask */
 	
 	g_assert (pKey != NULL);
 	g_assert (pNode != NULL);
@@ -1283,7 +1267,6 @@ GokKeyLabel* gok_keylabel_new (GokKey* pKey, gchar* pLabelText, guint level, gui
 
 	if (pLabelText != NULL)
 	{
-	        int len = strlen (pLabelText);
 		pNewLabel->Text = g_strdup (pLabelText);
 	}
 	
@@ -1524,7 +1507,6 @@ gok_key_get_image (GokKey* pKey)
 GtkWidget *
 gok_key_status_image (GokKey *key) 
 {
-	GokUIState state = key->ComponentState;
 	GtkWidget *image = NULL;
 	gchar *icon_name, *file;
 
@@ -1614,8 +1596,6 @@ gok_key_create_image_widget (GokKey* pKey)
 gchar* gok_key_get_label (GokKey* pKey)
 {
 	gchar* pTextReturned;
-	gchar* pToken;
-	gchar buffer[150];
 	GokKeyLabel* pKeyLabel;
 	gboolean bFoundLabel;
 	int  type = XkbAlphabeticIndex, keycode;
