@@ -183,8 +183,7 @@ GokOutput* gok_output_new (gint Type, gchar* Name, AccessibleKeySynthType Flag)
 	pNewOutput->pOutputNext = NULL;
 	pNewOutput->Flag = Flag;
 	pNewOutput->Type = Type;
-	pNewOutput->Name = (gchar*)g_malloc (strlen (Name) + 1);
-	strcpy (pNewOutput->Name, Name);
+	pNewOutput->Name = g_strdup (Name);
 
 	return pNewOutput;
 }
